@@ -1,5 +1,6 @@
 import asyncio
 import io
+import os
 import time
 from collections import defaultdict
 from datetime import datetime
@@ -71,13 +72,19 @@ def pytest_addoption(parser):
     )
 
     parser.addini(
-        Option.DISCORD_WEBHOOK.inioption_str, default=None, help=Option.DISCORD_WEBHOOK.help_msg,
+        Option.DISCORD_WEBHOOK.inioption_str,
+        default=None,
+        help=Option.DISCORD_WEBHOOK.help_msg,
     )
     parser.addini(
-        Option.DISCORD_VERBOSE.inioption_str, default=None, help=Option.DISCORD_VERBOSE.help_msg,
+        Option.DISCORD_VERBOSE.inioption_str,
+        default=None,
+        help=Option.DISCORD_VERBOSE.help_msg,
     )
     parser.addini(
-        Option.DISCORD_USERNAME.inioption_str, default=None, help=Option.DISCORD_USERNAME.help_msg,
+        Option.DISCORD_USERNAME.inioption_str,
+        default=None,
+        help=Option.DISCORD_USERNAME.help_msg,
     )
     parser.addini(
         Option.DISCORD_SUCCESS_ICON.inioption_str,
@@ -139,7 +146,7 @@ def _extract_longrepr(reporter: TerminalReporter) -> List[str]:
                 if value.longrepr:
                     messages.append(
                         "# {}: #{}\n{}".format(
-                            stat_key, i + 1, _decorate_code_block(lang="py", text=value.longrepr),
+                            stat_key, i + 1, _decorate_code_block(lang="py", text=value.longrepr)
                         )
                     )
             except AttributeError:
@@ -198,6 +205,14 @@ def _extract_longrepr_embeds(
     return embeds, exceeds_embeds_limit
 
 
+def _is_ci() -> bool:
+    CI = os.environ.get("CI")
+    if not CI:
+        return False
+
+    return CI.strip().lower() == "true"
+
+
 def _make_md_report(config: Config) -> str:
     from pytest_md_report import ColorPolicy, ZerosRender, make_md_report, retrieve_stat_count_map
 
@@ -228,6 +243,40 @@ def _make_md_report(config: Config) -> str:
         config.option.md_report_zeros = stash_md_report_zeros
 
 
+def _make_header(tests: int) -> str:
+    msgs = ["{} tests".format(tests)]
+
+    if _is_ci():
+        msgs.append("executed by CI")
+
+        if os.environ.get("GITHUB_ACTION"):
+            repo = os.environ.get("GITHUB_REPOSITORY")
+            workflow = os.environ.get("GITHUB_WORKFLOW")
+            msgs.append("({} {})".format(repo, workflow))
+
+    return "test summary info: {}".format(" ".join(msgs))
+
+
+def _make_summary_footer(reporter: TerminalReporter, verbosity_level: int) -> str:
+    import platform
+
+    msgs = []
+
+    if verbosity_level >= 1:
+        msgs.append(
+            "start at {}".format(
+                datetime.fromtimestamp(reporter._sessionstarttime).strftime("%d. %b %H:%M:%S%z")
+            )
+        )
+
+        uname = platform.uname()
+        host_info = "{} {} {} {}".format(uname.system, uname.node, uname.release, uname.machine)
+        python_info = "{} {}".format(platform.python_implementation(), platform.python_version())
+        msgs.extend([host_info, python_info])
+
+    return ",  ".join(msgs)
+
+
 _logs = []
 
 
@@ -291,11 +340,7 @@ def pytest_unconfigure(config):
     embed_summary = Embed(
         description="{} in {:.1f} seconds".format(message, duration), colour=colour
     )
-    embed_summary.set_footer(
-        text="start at {}".format(
-            datetime.fromtimestamp(reporter._sessionstarttime).strftime("%d. %b %H:%M:%S%z")
-        )
-    )
+    embed_summary.set_footer(text=_make_summary_footer(reporter, verbosity_level))
     embeds.append(embed_summary)
     embeds_len_ct += len(embed_summary.description) + len(embed_summary.footer)
 
@@ -330,7 +375,7 @@ def pytest_unconfigure(config):
         )
         embeds.extend(_embeds)
 
-    header = "test summary info: {} tests".format(sum(stat_count_map.values()))
+    header = _make_header(sum(stat_count_map.values()))
     attach_file = None
 
     if opt_retriever.retrieve_attach_file() or exceeds_embeds_limit:
@@ -376,7 +421,7 @@ async def _send_message(
             return
 
         await webhook.send(
-            header, username=username, avatar_url=avatar_url, embeds=embeds, file=attach_file,
+            header, username=username, avatar_url=avatar_url, embeds=embeds, file=attach_file
         )
 
 
